Module basic

Module basic 

Provides a “basic” implementation of the Chase.

This implementation is used as a reference for the correctness of other implementations of the Chase.

Note: The performance of chase::impl::basic is not a concern.

Structs

Evaluator
Evaluates a Sequent in a Model within a chase-step.
Model
Is a basic instance of ModelTrait with terms of type WitnessTerm.
Sequent
Is represented by a list of Literals in the body and a list of list of Literals in the head.

Enums

Literal
Represents atomic formulae in Sequent.
WitnessTerm
Is a straight forward implementation for WitnessTermTrait, where elements are of type E.