pub enum WitnessTerm {
Elem {
element: E,
},
Const {
constant: C,
},
App {
function: F,
terms: Vec<Self>,
},
}Expand description
Is a straight forward implementation for WitnessTermTrait, where elements are of type
E.
Variants
Elem
Wraps an instance of E, witnessing itself.
Const
Wraps an instance of C as a witness term.
App
Corresponds to a composite witness term, made by applying an instance of F to a list of
witness terms.