pub struct Sequent {
pub free_vars: Vec<V>,
pub body_literals: Vec<Literal>,
pub head_literals: Vec<Vec<Literal>>,
/* private fields */
}Expand description
Is represented by a list of Literals in the body and a list of list of Literals in the
head.
Fields
free_vars: Vec<V>Is the list of free variables in the sequent and is used for memoization.
body_literals: Vec<Literal>Represents the body of the sequent as a list of Literals. The literals in
body_literals are assumed to be conjoined.
Note: See here for more information about the structure of geometric sequents.
head_literals: Vec<Vec<Literal>>Represents the head of the sequent as a list of list of Literals. The literals in
each sublist of head_literals are assumed to be conjoined where the sublists are
disjointed with each other.
Note: See here for more information about the structure of geometric sequents.