pub enum WitnessTerm {
Elem {
element: Element,
},
Const {
constant: C,
},
App {
function: F,
terms: Vec<WitnessTerm>,
},
}Expand description
Implements WitnessTermTrait, with Element as the ElementType and serves as witness
terms for Model.
Variants
Elem
Wraps an instance of Element, witnessing itself.
Const
Wraps an instance of C as a witness term.
App
Corresponds to a composite witness term, made by applying an instance of F to a list of
witness terms.
Implementations
Sourceimpl WitnessTerm
impl WitnessTerm
Sourcepub fn witness(term: &Term, lookup: &impl Fn(&V) -> Element) -> WitnessTerm
pub fn witness(term: &Term, lookup: &impl Fn(&V) -> Element) -> WitnessTerm
Given a term and an assignment function assign from variables of the term to elements
of a Model, constructs a WitnessTerm.